"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _ApiClient = _interopRequireDefault(require("../ApiClient"));
var _JobListPage = _interopRequireDefault(require("../model/JobListPage"));
var _LinkedinJob = _interopRequireDefault(require("../model/LinkedinJob"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
/**
* JobsAPI service.
* @module api/JobsAPIApi
* @version 1.0.0
*/
var JobsAPIApi = /*#__PURE__*/function () {
  /**
  * Constructs a new JobsAPIApi. 
  * @alias module:api/JobsAPIApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function JobsAPIApi(apiClient) {
    _classCallCheck(this, JobsAPIApi);
    this.apiClient = apiClient || _ApiClient["default"].instance;
  }

  /**
   * Callback function to receive the result of the jobProfileEndpoint operation.
   * @callback module:api/JobsAPIApi~jobProfileEndpointCallback
   * @param {String} error Error message, if any.
   * @param {module:model/LinkedinJob} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Cost: 2 credits / successful request. Get structured data of a LinkedIn Job Profile
   * @param {String} url      URL of the LinkedIn Job Profile to target.      URL should be in the format of     `https://www.linkedin.com/jobs/view/<job_id>`.     [Jobs Listing Endpoint](#jobs-api-jobs-listing-endpoint)     can be used to retrieve a job URL.     
   * @param {module:api/JobsAPIApi~jobProfileEndpointCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/LinkedinJob}
   */
  _createClass(JobsAPIApi, [{
    key: "jobProfileEndpoint",
    value: function jobProfileEndpoint(url, callback) {
      var postBody = null;
      // verify the required parameter 'url' is set
      if (url === undefined || url === null) {
        throw new Error("Missing the required parameter 'url' when calling jobProfileEndpoint");
      }
      var pathParams = {};
      var queryParams = {
        'url': url
      };
      var headerParams = {};
      var formParams = {};
      var authNames = ['BearerAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _LinkedinJob["default"];
      return this.apiClient.callApi('/api/linkedin/job', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }

    /**
     * Callback function to receive the result of the jobsListingEndpoint operation.
     * @callback module:api/JobsAPIApi~jobsListingEndpointCallback
     * @param {String} error Error message, if any.
     * @param {module:model/JobListPage} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Cost: 2 credits / successful request. List jobs posted by a company on LinkedIn
     * @param {String} searchId      The `search_id` of the company on LinkedIn.     You can get the `search_id` of a LinkedIn company via     [Company Profile API](#company-api-company-profile-endpoint).     
     * @param {module:api/JobsAPIApi~jobsListingEndpointCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/JobListPage}
     */
  }, {
    key: "jobsListingEndpoint",
    value: function jobsListingEndpoint(searchId, callback) {
      var postBody = null;
      // verify the required parameter 'searchId' is set
      if (searchId === undefined || searchId === null) {
        throw new Error("Missing the required parameter 'searchId' when calling jobsListingEndpoint");
      }
      var pathParams = {};
      var queryParams = {
        'search_id': searchId
      };
      var headerParams = {};
      var formParams = {};
      var authNames = ['BearerAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _JobListPage["default"];
      return this.apiClient.callApi('/api/v2/linkedin/company/job', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);
  return JobsAPIApi;
}();
exports["default"] = JobsAPIApi;