"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _ApiClient = _interopRequireDefault(require("../ApiClient"));
var _LinkedinSchool = _interopRequireDefault(require("../model/LinkedinSchool"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
/**
* SchoolAPI service.
* @module api/SchoolAPIApi
* @version 1.0.0
*/
var SchoolAPIApi = /*#__PURE__*/function () {
  /**
  * Constructs a new SchoolAPIApi. 
  * @alias module:api/SchoolAPIApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function SchoolAPIApi(apiClient) {
    _classCallCheck(this, SchoolAPIApi);
    this.apiClient = apiClient || _ApiClient["default"].instance;
  }

  /**
   * Callback function to receive the result of the schoolProfileEndpoint operation.
   * @callback module:api/SchoolAPIApi~schoolProfileEndpointCallback
   * @param {String} error Error message, if any.
   * @param {module:model/LinkedinSchool} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Cost: 1 credit / successful request. Get structured data of a LinkedIn School Profile
   * @param {String} url      URL of the LinkedIn School Profile to crawl.      URL should be in the format of `https://www.linkedin.com/school/<public_identifier>`     
   * @param {Object} opts Optional parameters
   * @param {String} opts.useCache `if-present` The default behavior. Fetches profile from cache regardless of age of profile. If profile is not available in cache, API will attempt to source profile externally.  `if-recent` API will make a best effort to return a fresh profile no older than 29 days.Costs an extra `1` credit on top of the cost of the base endpoint.
   * @param {module:api/SchoolAPIApi~schoolProfileEndpointCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/LinkedinSchool}
   */
  _createClass(SchoolAPIApi, [{
    key: "schoolProfileEndpoint",
    value: function schoolProfileEndpoint(url, opts, callback) {
      opts = opts || {};
      var postBody = null;
      // verify the required parameter 'url' is set
      if (url === undefined || url === null) {
        throw new Error("Missing the required parameter 'url' when calling schoolProfileEndpoint");
      }
      var pathParams = {};
      var queryParams = {
        'url': url,
        'use_cache': opts['useCache']
      };
      var headerParams = {};
      var formParams = {};
      var authNames = ['BearerAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _LinkedinSchool["default"];
      return this.apiClient.callApi('/api/linkedin/school', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);
  return SchoolAPIApi;
}();
exports["default"] = SchoolAPIApi;